Composition
===========

.. toctree::
   :maxdepth: 1

   *Subclasses:*
   CompositionFunctionApproximator
   AutodiffComposition

.. automodule:: psyneulink.core.compositions.composition
   :members:
   :exclude-members: Parameters, show_structure
